from django.contrib.auth.forms import UserCreationForm
from django import forms
from django.utils.translation import gettext_lazy as _

from member.models import TFJMUser


class SignUpForm(UserCreationForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["first_name"].required = True
        self.fields["last_name"].required = True
        self.fields["role"].choices = [
            ('', _("Choose a role...")),
            ('participant', _("Participant")),
            ('encadrant', _("Encadrant")),
        ]

    class Meta:
        model = TFJMUser
        fields = (
            'role',
            'email',
            'first_name',
            'last_name',
            'birth_date',
            'gender',
            'address',
            'postal_code',
            'city',
            'country',
            'phone_number',
            'school',
            'student_class',
            'responsible_name',
            'responsible_phone',
            'responsible_email',
            'description',
        )


class TFJMUserForm(forms.ModelForm):
    class Meta:
        model = TFJMUser
        fields = ('last_name', 'first_name', 'email', 'phone_number', 'gender', 'birth_date', 'address', 'postal_code',
                  'city', 'country', 'school', 'student_class', 'responsible_name', 'responsible_phone',
                  'responsible_email',)


class CoachUserForm(forms.ModelForm):
    class Meta:
        model = TFJMUser
        fields = ('last_name', 'first_name', 'email', 'phone_number', 'gender', 'birth_date', 'address', 'postal_code',
                  'city', 'country', 'description',)


class AdminUserForm(forms.ModelForm):
    class Meta:
        model = TFJMUser
        fields = ('last_name', 'first_name', 'email', 'phone_number', 'description',)
