"""tfjm URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
import re

from django.conf import settings
from django.contrib import admin
from django.contrib.staticfiles.views import serve
from django.urls import path, include, re_path
from django.views.defaults import bad_request, permission_denied, page_not_found, server_error
from django.views.generic import TemplateView, RedirectView

from member.views import DocumentView

urlpatterns = [
    path('', TemplateView.as_view(template_name="index.html"), name="index"),
    path('i18n/', include('django.conf.urls.i18n')),
    path('admin/doc/', include('django.contrib.admindocs.urls')),
    path('admin/', admin.site.urls, name="admin"),
    path('accounts/', include('django.contrib.auth.urls')),

    path('member/', include('member.urls')),
    path('tournament/', include('tournament.urls')),

    path("media/<str:file>/", DocumentView.as_view(), name="document"),

    path('api/', include('api.urls')),

    re_path(r'^%s(?P<path>.*)$' % re.escape(settings.STATIC_URL.lstrip('/')), serve),

    # Supporting old paths
    path('inscription/', RedirectView.as_view(pattern_name="member:signup")),
    path('connexion/', RedirectView.as_view(pattern_name="login")),
    path('tournois/', RedirectView.as_view(pattern_name="tournament:list")),
]

handler400 = bad_request
handler403 = permission_denied
handler404 = page_not_found
handler500 = server_error
